==> kdebase-3.1.3.tar.bz2: kdebase-3.1.3/kwin/clients/web/WebButtonMaximize.cpp <==
/*
  'Web' kwin client

  Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#include "WebButtonMaximize.h"

namespace Web {

using namespace KWinInternal;

static unsigned char maximize_bits[] =
{
   0xfc, 0xf8, 0xf0, 0xe0, 0xc0, 0x80, 0x00, 0x00
};

static unsigned char unmaximize_bits[] =
{
   0x00, 0x00, 0x01, 0x03, 0x07, 0x0f, 0x1f, 0x3f
};

WebButtonMaximize::WebButtonMaximize(bool max, QWidget * parent)
  : WebButton(parent, i18n("Maximize"))
{
  QBitmap b(8, 8, max ? unmaximize_bits : maximize_bits, true /* isXBitmap */);
  b.setMask(b);
  setBitmap(b);
}

  void
WebButtonMaximize::slotMaximizeChange(bool max)
{
  QBitmap b(8, 8, max ? unmaximize_bits : maximize_bits, true /* isXBitmap */);
  b.setMask(b);
  setBitmap(b);
  setTipText(max ? i18n("Restore") : i18n("Maximize"));
}

  void
WebButtonMaximize::clickEvent(int button)
{
  emit(maximize(button));
}

}

#include "WebButtonMaximize.moc"
// vim:ts=2:sw=2:tw=78:set et:

==> kdebase-3.4.0.tar.bz2: kdebase-3.4.0/kwin/clients/web/WebButtonMaximize.cpp <==
/*
  'Web' kwin client

  Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#include "WebButtonMaximize.h"

namespace Web {

static unsigned char maximize_bits[] =
{
   0xfc, 0xf8, 0xf0, 0xe0, 0xc0, 0x80, 0x00, 0x00
};

static unsigned char unmaximize_bits[] =
{
   0x00, 0x00, 0x01, 0x03, 0x07, 0x0f, 0x1f, 0x3f
};

WebButtonMaximize::WebButtonMaximize(bool max, QWidget * parent, WebClient* deco)
  : WebButton(parent, i18n("Maximize"), deco)
{
  QBitmap b(8, 8, max ? unmaximize_bits : maximize_bits, true /* isXBitmap */);
  b.setMask(b);
  setBitmap(b);
}

  void
WebButtonMaximize::slotMaximizeChange(bool max)
{
  QBitmap b(8, 8, max ? unmaximize_bits : maximize_bits, true /* isXBitmap */);
  b.setMask(b);
  setBitmap(b);
  setTipText(max ? i18n("Restore") : i18n("Maximize"));
}

  void
WebButtonMaximize::clickEvent(int button)
{
  emit(maximize(button));
}

}

#include "WebButtonMaximize.moc"
// vim:ts=2:sw=2:tw=78:set et:
